@@ -1,4 +1,3 @@
-from pprint import pprint
 from typing import Any, Dict, List
 
 from discord_markdown_ast_parser.lexer import lex
@@ -22,10 +21,3 @@ def parse_to_dict(text) -> List[Dict[str, Any]]:
     """
     node_ast = parse(text)
     return [node.to_dict() for node in node_ast]
-
-
-if __name__ == "__main__":
-    with open("shit.txt", "r") as f:
-        shit = f.read()
-
-    pprint(parse_to_dict(shit))
